get_tool

Function get_tool 

pub fn get_tool(name: &str) -> Option<Arc<Box<dyn Tool + Send + Sync>>>
Retrieves a tool by name from the global registry.

Arguments

  • name - The name of the tool to retrieve

Returns

The tool if found, or None if no tool with that name is registered.