pub struct PresetToolAgent { /* private fields */ }Expand description
Agent that exposes a workflow as a callable tool.
This agent registers itself as a tool that can be invoked by LLMs.
When called, it forwards the arguments to the tool_in output port
and waits for a response on the tool_out input port.
Configuration
name- The tool name (defaults to agent definition name)description- Human-readable description of the toolparameters- JSON Schema describing the tool’s parameters
Ports
- Input
tool_out- Receives the tool’s result from the workflow - Output
tool_in- Emits the tool call arguments to the workflow
Implementations
Sourceimpl PresetToolAgent
impl PresetToolAgent
pub const DEF_NAME: &'static str = "modular_agent_core::tool::PresetToolAgent"
pub fn def_name() -> &'static str
pub fn agent_definition() -> AgentDefinition
pub fn register(ma: &ModularAgent)