ModularAgent

Struct ModularAgent 

pub struct ModularAgent { /* private fields */ }

Implementations

Source

impl ModularAgent

pub fn new() -> Self

pub fn init() -> Result<Self, AgentError>

Initialize ModularAgent.

pub async fn ready(&self) -> Result<(), AgentError>

Prepare ModularAgent to be ready.

pub fn quit(&self)

Quit ModularAgent.

pub fn new_preset(&self) -> Result<String, AgentError>

Create a new preset. Returns the id of the new preset.

pub fn new_preset_with_name(&self, name: String) -> Result<String, AgentError>

Create a new preset with the given name. Returns the id of the new preset.

pub fn get_preset(&self, id: &str) -> Option<Arc<AsyncMutex<Preset>>>

Get a preset by id.

pub fn add_preset(&self, spec: PresetSpec) -> Result<String, AgentError>

Add a new preset with the given spec, and returns the id of the new preset.

The ids of the given spec, including agents and connections, are changed to new unique ids.

pub fn add_preset_with_name( &self, spec: PresetSpec, name: String, ) -> Result<String, AgentError>

Add a new preset with the given name and spec, and returns the id of the new preset.

The ids of the given spec, including agents and connections, are changed to new unique ids.

pub async fn remove_preset(&self, id: &str) -> Result<(), AgentError>

Remove an preset by id.

pub async fn start_preset(&self, id: &str) -> Result<(), AgentError>

Start a preset by id.

pub async fn stop_preset(&self, id: &str) -> Result<(), AgentError>

Stop a preset by id.

pub async fn open_preset_from_file( &self, path: &str, name: Option<String>, ) -> Result<String, AgentError>

Open a preset

pub async fn save_preset(&self, id: &str, path: &str) -> Result<(), AgentError>

Save a preset.

pub async fn get_preset_spec(&self, id: &str) -> Option<PresetSpec>

Get the current preset spec by id.

pub async fn update_preset_spec( &self, id: &str, value: &Value, ) -> Result<(), AgentError>

Update the preset spec

pub async fn get_preset_info(&self, id: &str) -> Option<PresetInfo>

Get info of the preset by id.

pub async fn get_preset_infos(&self) -> Vec<PresetInfo>

Get infos of all presets.

pub fn register_agent_definiton(&self, def: AgentDefinition)

Register an agent definition.

pub fn get_agent_definitions(&self) -> AgentDefinitions

Get all agent definitions.

pub fn get_agent_definition(&self, def_name: &str) -> Option<AgentDefinition>

Get an agent definition by name.

pub fn get_agent_config_specs(&self, def_name: &str) -> Option<AgentConfigSpecs>

Get the config specs of an agent definition by name.

pub async fn get_agent_spec(&self, agent_id: &str) -> Option<AgentSpec>

Get the agent spec by id.

pub async fn update_agent_spec( &self, agent_id: &str, value: &Value, ) -> Result<(), AgentError>

Update the agent spec by id.

pub fn new_agent_spec(&self, def_name: &str) -> Result<AgentSpec, AgentError>

Create a new agent spec from the given agent definition name.

pub async fn add_agent( &self, preset_id: String, spec: AgentSpec, ) -> Result<String, AgentError>

Add an agent to the specified preset, and returns the id of the newly added agent.

pub fn get_agent( &self, agent_id: &str, ) -> Option<Arc<AsyncMutex<Box<dyn Agent>>>>

Get the agent by id.

pub async fn add_connection( &self, preset_id: &str, connection: ConnectionSpec, ) -> Result<(), AgentError>

Add a connection to the specified preset.

pub async fn add_agents_and_connections( &self, preset_id: &str, agents: &Vec<AgentSpec>, connections: &Vec<ConnectionSpec>, ) -> Result<(Vec<AgentSpec>, Vec<ConnectionSpec>), AgentError>

Add agents and connections to the specified preset.

The ids of the given agents and connections are changed to new unique ids. The agents are not started automatically, even if the preset is running.

pub async fn remove_agent( &self, preset_id: &str, agent_id: &str, ) -> Result<(), AgentError>

Remove an agent from the specified preset.

If the agent is running, it will be stopped first.

pub async fn remove_connection( &self, preset_id: &str, connection: &ConnectionSpec, ) -> Result<(), AgentError>

Remove a connection from the specified preset.

pub async fn start_agent(&self, agent_id: &str) -> Result<(), AgentError>

Start an agent by id.

pub async fn stop_agent(&self, agent_id: &str) -> Result<(), AgentError>

Stop an agent by id.

pub async fn set_agent_configs( &self, agent_id: String, configs: AgentConfigs, ) -> Result<(), AgentError>

Set configs for an agent by id.

pub fn get_global_configs(&self, def_name: &str) -> Option<AgentConfigs>

Get global configs for the agent definition by name.

pub fn set_global_configs(&self, def_name: String, configs: AgentConfigs)

Set global configs for the agent definition by name.

pub fn get_global_configs_map(&self) -> AgentConfigsMap

Get the global configs map.

pub fn set_global_configs_map(&self, new_configs_map: AgentConfigsMap)

Set the global configs map.

pub async fn send_agent_out( &self, agent_id: String, ctx: AgentContext, port: String, value: AgentValue, ) -> Result<(), AgentError>

Send output from an agent. (Async version)

pub fn try_send_agent_out( &self, agent_id: String, ctx: AgentContext, port: String, value: AgentValue, ) -> Result<(), AgentError>

Send output from an agent.

pub async fn write_board_value( &self, name: String, value: AgentValue, ) -> Result<(), AgentError>

Write a value to the board.

pub async fn write_var_value( &self, preset_id: &str, name: &str, value: AgentValue, ) -> Result<(), AgentError>

Write a value to the variable board.

pub fn subscribe(&self) -> Receiver<MAKEvent>

Subscribe to all ModularAgent events.

pub fn subscribe_to_event<F, T>(&self, filter_map: F) -> UnboundedReceiver<T>
where F: FnMut(MAKEvent) -> Option<T> + Send + 'static, T: Send + 'static,

Subscribe to a specific type of MAKEvent.

It takes a closure that filters and maps the events, and returns an mpsc::UnboundedReceiver that will receive only the successfully mapped events.