pub async fn call_tool( ctx: AgentContext, name: &str, args: AgentValue, ) -> Result<AgentValue, AgentError>
Invokes a tool by name with the given arguments.
ctx
name
args
The tool’s result, or an error if the tool is not found or fails.