pub struct CallToolMessageAgent { /* private fields */ }Expand description
Agent that processes tool calls from LLM messages.
When an LLM response contains tool calls, this agent executes them and outputs the results as tool response messages.
Configuration
tools- Optional regex patterns to filter which tools can be called
Ports
- Input
message- LLM message that may contain tool calls - Output
message- Tool response messages (one per tool call)
Implementations
Sourceimpl CallToolMessageAgent
impl CallToolMessageAgent
pub const DEF_NAME: &'static str = "modular_agent_core::tool::CallToolMessageAgent"
pub fn def_name() -> &'static str
pub fn agent_definition() -> AgentDefinition
pub fn register(ma: &ModularAgent)